package selenium.account;

import org.junit.Assert;
import org.junit.Test;
import org.openqa.selenium.By;
import org.openqa.selenium.WebElement;
import org.openqa.selenium.chrome.ChromeDriver;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;
import selenium.config.Config;
import selenium.login.LoginPOM;

import java.io.IOException;
import java.time.Duration;
import java.util.Map;
import java.util.concurrent.TimeUnit;

public class AccountSettingsTest {

    @Test
    public void runAccountsPageTests() throws IOException {
        //Setup
        System.setProperty("webdriver.chrome.driver", "/Users/ccottier/Desktop/chromedriver");

        ChromeDriver driver = new ChromeDriver();
        driver.manage().timeouts().implicitlyWait(40, TimeUnit.SECONDS);
        Map<String,String> config = new Config().getProps();

        LoginPOM loginPage = new LoginPOM(driver);
        AccountSettingsPOF accountSettingsPage = new AccountSettingsPOF(driver);

        //Navigate to accounts page and sign in
        accountSettingsPage.navigateToUrl(accountSettingsPage.getAccountSettingsUrl());
        loginPage.login(config.get("email"), config.get("password"));

        // Get accounts page values
        Boolean waitInputs = new WebDriverWait(driver, 15)
                .until(ExpectedConditions.attributeToBeNotEmpty(accountSettingsPage.firstNameInput,"value"));

        String firstName = accountSettingsPage.firstNameInput.getAttribute("value");
        String lastName = accountSettingsPage.lastNameInput.getAttribute("value");
        String email = accountSettingsPage.emailInput.getAttribute("value");
        String phoneNumber = accountSettingsPage.phoneNumberInput.getAttribute("value");
        String clubCardNumber = accountSettingsPage.clubCardNumber.getText();

        //Compare to expected and assert

        Assert.assertEquals("First name not equal to account details", config.get("first_name"),firstName);
        Assert.assertEquals("Last name not equal to account details", config.get("last_name"), lastName);
        Assert.assertEquals("Email not equal to account details", config.get("email"), email);
        Assert.assertEquals("Phone number not equal to account details", config.get("phone_number"), phoneNumber);
        Assert.assertTrue("Club card number invalid", !clubCardNumber.equals(""));

        driver.close();

    }
}
